precision highp float;
uniform sampler2D inputImageTexture;
uniform sampler2D inputImageTexture2;
varying highp vec2 textureCoordinate;
varying highp vec2 textureCoordinate2;

uniform highp vec2 realWH;
uniform highp float mixRatio;//混合参数

float compareimg(vec3 s1, vec3 s2)
{
    float s = 0.0, a = 0.0, b = 0.0;

    s += s1.x * s2.x;
    a += s1.x * s1.x;
    b += s2.x * s2.x;

    s += s1.y * s2.y;
    a += s1.y * s1.y;
    b += s2.y * s2.y;

    s += s1.z * s2.z;
    a += s1.z * s1.z;
    b += s2.z * s2.z;

    float sa = sqrt(a);
    float sb = sqrt(b);
    float resultnum = s / (sa * sb);
    return resultnum;
}

highp vec4 blendColorMultiply(highp vec4 c1,highp vec4 c2){
    highp vec4 outputColorMultiply = vec4(c1.r*c2.r,c1.g*c2.g,c1.b*c2.b,1.0);
    return outputColorMultiply;
}

highp vec4 blendNormal(highp vec4 c1, highp vec4 c2,highp float mixB)
{
    vec4 outputColor;
    outputColor.r = c1.r*mixB + c2.r * c2.a * (1.0 - c1.a*mixB);
    outputColor.g = c1.g*mixB + c2.g * c2.a * (1.0 - c1.a*mixB);
    outputColor.b = c1.b*mixB + c2.b * c2.a * (1.0 - c1.a*mixB);
    outputColor.a = c1.a + c2.a * (1.0 - c1.a);
    return outputColor;
}

vec4 blendSoft(vec4 base, vec4 overlay)
{
          lowp float nr = base.r;
          if(base.r <= 0.5){
              nr = (2.0 * overlay.r - 1.0)*(base.r - base.r * base.r) + base.r;
          }else{
              nr = (2.0 * overlay.r - 1.0) * (sqrt(base.r) - base.r) + base.r;
          }
         lowp float ng = base.g;
         if(base.g <= 0.5){
             ng = (2.0 * overlay.g - 1.0)*(base.g - base.g * base.g) + base.g;
         }else{
             ng = (2.0 * overlay.g - 1.0) * (sqrt(base.g) - base.g) + base.g;
         }
         lowp float nb = base.b;
         if(base.b <= 0.5){
             nb = (2.0 * overlay.b - 1.0)*(base.b - base.b * base.b) + base.b;
         }else{
             nb = (2.0 * overlay.b - 1.0) * (sqrt(base.b) - base.b) + base.b;
         }
          vec4 newColor = vec4(nr, ng, nb, base.a);
          return newColor;
}

void main(void)
{
    vec4 oriColor = texture2D(inputImageTexture, textureCoordinate);
    vec4 allForOneColor = texture2D(inputImageTexture2, textureCoordinate2);


    vec4 resultColor = blendNormal(oriColor,allForOneColor,mixRatio);


    gl_FragColor = resultColor;
}