precision highp float;
uniform sampler2D inputImageTexture;
uniform sampler2D inputImageTexture2;//图片合集   10*5
uniform sampler2D inputImageTexture3;//色彩合集  图片数目*3
varying highp vec2 textureCoordinate;
varying highp vec2 textureCoordinate2;
varying highp vec2 textureCoordinate3;

uniform highp vec2 realWH;
uniform highp float countOneLine;//控制一行个数 范围1~100
uniform highp float picCount;//图片个数
uniform highp float mixRatio;//混合参数

float compareimg(vec3 s1, vec3 s2)
{
    float s = 0.0, a = 0.0, b = 0.0;

    s += s1.x * s2.x;
    a += s1.x * s1.x;
    b += s2.x * s2.x;

    s += s1.y * s2.y;
    a += s1.y * s1.y;
    b += s2.y * s2.y;

    s += s1.z * s2.z;
    a += s1.z * s1.z;
    b += s2.z * s2.z;

    float sa = sqrt(a);
    float sb = sqrt(b);
    float resultnum = s / (sa * sb);
    return resultnum;
}

vec4 findSuitColor(vec2 curUVMosaic, vec4 oriMosaicColor, vec2 percentPosInItem){
    float suitIndex = 1.0;
    vec3 suitColor = vec3(1.0, 1.0, 1.0);
    float stepL = 1.0/picCount;
    float minDis = 0.0;
    float suitColorIndex = 0.0;//第几个颜色符合
    for (float j = 0.0; j<picCount; j += 1.0){
        vec4 oriMosaicColor1 = texture2D(inputImageTexture3, vec2(j*stepL, 0.0));
        float distance1 = compareimg(oriMosaicColor1.rgb, oriMosaicColor.rgb);
        //如过当前距离小于最小距离，返回0，否则返回1
        float judge = step(minDis, distance1);
        judge = 1.0 - judge;
        minDis = minDis*judge+distance1*(1.0 - judge);
        suitColorIndex = suitColorIndex*judge+j*(1.0 - judge);
    }


    //suitIndex从0开始
    //0  1  2  3  4  5 6 7 8 9
    //10 11

    //图片合集   10*5
    float hIndex = floor(suitColorIndex/10.0);

    float wIndex = suitColorIndex - hIndex*10.0;
    float oneItemW = 0.1;
    float oneItemH = 0.2;

    vec2 pickColorPos = vec2(wIndex*oneItemW+percentPosInItem.x*oneItemW, hIndex*oneItemH+percentPosInItem.y*oneItemH);
    vec4 resultColor = texture2D(inputImageTexture2, pickColorPos);
    return resultColor;
}

vec4 blendSoft(vec4 base, vec4 overlay)
{
          lowp float nr = base.r;
          if(base.r <= 0.5){
              nr = (2.0 * overlay.r - 1.0)*(base.r - base.r * base.r) + base.r;
          }else{
              nr = (2.0 * overlay.r - 1.0) * (sqrt(base.r) - base.r) + base.r;
          }
         lowp float ng = base.g;
         if(base.g <= 0.5){
             ng = (2.0 * overlay.g - 1.0)*(base.g - base.g * base.g) + base.g;
         }else{
             ng = (2.0 * overlay.g - 1.0) * (sqrt(base.g) - base.g) + base.g;
         }
         lowp float nb = base.b;
         if(base.b <= 0.5){
             nb = (2.0 * overlay.b - 1.0)*(base.b - base.b * base.b) + base.b;
         }else{
             nb = (2.0 * overlay.b - 1.0) * (sqrt(base.b) - base.b) + base.b;
         }
          vec4 newColor = vec4(nr, ng, nb, base.a);
          return newColor;
}

void main(void)
{
    vec4 oriColor = texture2D(inputImageTexture, textureCoordinate);

    vec2 mosaicSize = vec2(realWH.x/countOneLine, realWH.x/countOneLine);

    //当前真实坐标
    vec2 xy = vec2(textureCoordinate.x * realWH.x, textureCoordinate.y * realWH.y);

    //这个坐标是马赛克方格左上角的坐标,且是真实宽高非0~1
    vec2 xyMosaic = vec2(floor(xy.x / mosaicSize.x) * mosaicSize.x, floor(xy.y / mosaicSize.y) * mosaicSize.y);


    vec2 uvMosaic_center = vec2((xyMosaic.x+mosaicSize.x*0.5) / realWH.x, (xyMosaic.y+mosaicSize.y*0.5) / realWH.y);
    vec2 uvMosaic_leftTop = vec2((xyMosaic.x) / realWH.x, (xyMosaic.y) / realWH.y);
    vec2 uvMosaic_rightTop = vec2((xyMosaic.x+mosaicSize.x) / realWH.x, (xyMosaic.y) / realWH.y);
    vec2 uvMosaic_leftBotto = vec2((xyMosaic.x) / realWH.x, (xyMosaic.y+mosaicSize.y) / realWH.y);
    vec2 uvMosaic_rightBottom = vec2((xyMosaic.x+mosaicSize.x) / realWH.x, (xyMosaic.y+mosaicSize.y) / realWH.y);
    vec4 centerColor = texture2D(inputImageTexture, uvMosaic_center);
    vec4 ltColor = texture2D(inputImageTexture, uvMosaic_leftTop);
    vec4 rtColor = texture2D(inputImageTexture, uvMosaic_rightTop);
    vec4 lbColor = texture2D(inputImageTexture, uvMosaic_leftBotto);
    vec4 rbColor = texture2D(inputImageTexture, uvMosaic_rightBottom);
    vec4 avgColor = vec4((ltColor.rgb+rtColor.rgb+lbColor.rbg+rbColor.rgb+centerColor.rgb)/5.0,1.0);

    //0~1
    vec2 percentPosInItem = vec2((xy.x - xyMosaic.x)/mosaicSize.x, (xy.y - xyMosaic.y)/mosaicSize.y);

    vec4 oriMosaicColor = avgColor;

    vec4 findColor = findSuitColor(uvMosaic_center, oriMosaicColor, percentPosInItem);
    vec4 resultColor = vec4(mix(oriColor.rgb, findColor.rgb, mixRatio), 1.0);

    gl_FragColor = resultColor;
}